@@ -3,15 +3,21 @@
 package Pinto::PackageSpec;
 
 use Moose;
-
+use MooseX::MarkAsMethods (autoclean => 1);
 use MooseX::Types::Moose qw(Str);
-use Pinto::Types qw(Version);
 
+use Module::Corelist;
+use English qw(-no_match_vars);
+
+use Pinto::Types qw(Version);
+use Pinto::Exception qw(throw);
+
+use version;
 use overload ('""' => 'to_string');
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_01'; # VERSION
+our $VERSION = '0.065_02'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -46,6 +52,32 @@ around BUILDARGS => sub {
 
 #------------------------------------------------------------------------------
 
+sub is_core {
+    my ($self, %args) = @_;
+
+    ## no critic qw(PackageVar);
+
+    my $pv = version->parse($args{in}) || $PERL_VERSION;
+    my $core_modules = $Module::CoreList::version{ $pv->numify + 0 };
+
+    throw "Invalid perl version $pv" if not $core_modules;
+
+    return 0 if not exists $core_modules->{$self->name};
+    return 0 if $self->version > $core_modules->{$self->name};
+    return 1;
+}
+
+
+#-------------------------------------------------------------------------------
+
+sub is_perl {
+    my ($self) = @_;
+
+    return $self->name eq 'perl' ? 1 : 0;
+}
+
+#-------------------------------------------------------------------------------
+
 
 sub to_string {
     my ($self) = @_;
@@ -71,7 +103,7 @@ Pinto::PackageSpec - Specifies a package by name and version
 
 =head1 VERSION
 
-version 0.065_01
+version 0.065_02
 
 =head1 METHODS
 
