@@ -27,7 +27,7 @@ use base qw(Exporter);
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.065_01'; # VERSION
+our $VERSION = '0.065_02'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -38,13 +38,12 @@ Readonly our @EXPORT_OK => qw(
     current_utc_time
     current_time_offset
     current_username
+    debug
     decamelize
     indent_text
     interpolate
     is_interactive
-    is_stack_all
     is_system_prop
-    is_vcs_file
     isa_perl
     itis
     md5
@@ -55,7 +54,9 @@ Readonly our @EXPORT_OK => qw(
     title_text
     trim_text
     truncate_text
+    user_colors
     uuid
+    whine
 );
 
 Readonly our %EXPORT_TAGS => ( all => \@EXPORT_OK );
@@ -112,19 +113,6 @@ sub isa_perl {
 #-------------------------------------------------------------------------------
 
 
-Readonly my %VCS_FILES => (map {$_ => 1} qw(.svn .git .gitignore CVS));
-
-sub is_vcs_file {
-    my ($file) = @_;
-
-    $file = file($file) unless eval { $file->isa('Path::Class::File') };
-
-    return exists $VCS_FILES{ $file->basename() };
-}
-
-#-------------------------------------------------------------------------------
-
-
 sub mtime {
     my ($file) = @_;
 
@@ -357,15 +345,6 @@ sub mksymlink {
 #-------------------------------------------------------------------------------
 
 
-sub is_stack_all {
-    my $stack_name = shift;
-
-    return defined $stack_name && $stack_name eq $PINTO_STACK_NAME_ALL;
-}
-
-#-------------------------------------------------------------------------------
-
-
 sub is_system_prop {
     my $string = shift;
 
@@ -381,6 +360,46 @@ sub uuid {
 }
 
 
+#-------------------------------------------------------------------------------
+
+sub user_colors {
+    my $colors = $ENV{PINTO_COLORS} || $ENV{PINTO_COLOURS};
+
+    return $PINTO_DEFAULT_COLORS if not $colors;
+
+    return [ split m/\s* , \s*/x, $colors ];
+}
+
+#-------------------------------------------------------------------------------
+
+
+sub debug {
+    my ($it) = @_;
+
+    # TODO: Use Carp instead?
+
+    return 1 if not $ENV{PINTO_DEBUG};
+
+    $it = $it->() if ref $it eq 'CODE';
+    my ($file, $line) = (caller)[1,2];
+    print { *STDERR } "$it in $file at line $line\n";
+
+    return 1;
+}
+
+#-------------------------------------------------------------------------------
+
+
+sub whine {
+    my ($message) = @_;
+
+    chomp $message;
+
+    warn $message . "\n";
+
+    return 1;
+}
+
 #-------------------------------------------------------------------------------
 1;
 
@@ -396,7 +415,7 @@ Pinto::Util - Static utility functions for Pinto
 
 =head1 VERSION
 
-version 0.065_01
+version 0.065_02
 
 =head1 DESCRIPTION
 
@@ -433,11 +452,6 @@ Return true if C<$path_or_url> appears to point to a release of perl
 itself.  This is based on some file naming patterns that I've seen in
 the wild.  It may not be completely accurate.
 
-=head2 is_vcs_file( $path );
-
-Returns true if C<$path> appears to point to a file that is an
-internal part of a version control system.
-
 =head2 mtime( $file )
 
 Returns the last modification time (in epoch seconds) for the C<file>.
@@ -541,11 +555,6 @@ Creates a symlink between the two files.  No checks are performed to see
 if either path is valid or already exists.  Throws an exception if the
 operation fails or is not supported.
 
-=head2 is_stack_all($stack_name)
-
-Returns true if the given C<$stack_name> matches the name of the magical
-C<STACK_ALL> which represents all stacks.
-
 =head2 is_system_prop($string)
 
 Returns true if C<$string> is the name of a system property.
@@ -555,6 +564,19 @@ Returns true if C<$string> is the name of a system property.
 Returns a UUID as a string.  Currently, the UUID is derived from
 random numbers.
 
+=head2 debug( $message )
+
+=head2 debug( sub {...} )
+
+Writes the message on STDERR if the C<PINTO_DEBUG> environment variable is true.
+If the argument is a subroutine, it will be invoked and its output will be
+written instead.  Always returns true.
+
+=head2 whine( $message )
+
+Just calls warn(), but always appends the newline so that line numbers are
+suppressed.
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
